﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.DockManager;
using Infragistics.Windows.DockManager.Events;

namespace XamDocLayoutsaving
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private SplitPane _parentSplitPane;
        private TabGroupPane _parentTabGroupPane;
        public MainWindow()
        {
            InitializeComponent();
            _parentSplitPane = new SplitPane() {Name = "ParentSplitPane"};
            _parentTabGroupPane = new TabGroupPane() {Name="ParentTabGroupPane"};
            _parentSplitPane.Panes.Add(_parentTabGroupPane);

            AppDockManager.Panes.Add(_parentSplitPane);
        }

        private void ButtonAddOnClick(object sender, RoutedEventArgs e)
        {
            var panesNumber = AppDockManager.GetPanes(PaneNavigationOrder.ActivationOrder).Count() + 1;
            var id = Guid.NewGuid().ToString();
            var tag = "Pane :" + panesNumber + Environment.NewLine + id;

            var newPane = new ContentPane()
            {
                Name = string.Format($"Parent_Content_Pane_{panesNumber}"),
                Header = "Parent Content Pane " + panesNumber ,
                SerializationId = id,
                IsEnabled = true,
                Tag = tag,
                Visibility = Visibility.Visible,
            };

            var childDockManager = new XamDockManager();
            var splitpane = new SplitPane();
            childDockManager.Panes.Add(splitpane);

            var childDockMgrTabGroupPane = new TabGroupPane() {Name = "ChildTabGroupPane"};
            childDockMgrTabGroupPane.Items.Add(GetChildContentPane(childDockManager.GetPanes(PaneNavigationOrder.ActivationOrder).Count() + 1));

            newPane.Content = childDockManager;
            splitpane.Panes.Add(childDockMgrTabGroupPane);

            _parentTabGroupPane.Items.Add(newPane);
            
            newPane.Activate();
        }

        private ContentPane GetChildContentPane(int paneNumber)
        {
            var id = Guid.NewGuid().ToString();
            var tag = "Pane :" + paneNumber + Environment.NewLine + id;
            
            var newPane = new ContentPane()
            {
                Name = "ChildPane" + id.Replace("-", ""),
                Header = "Child " + paneNumber,
                SerializationId = id,
                IsEnabled = true,
                Tag = tag,
                Visibility = Visibility.Visible,
                Content = new ContentUserControl(tag)
            };
            return newPane;
        }

        private void ButtonSaveOnClick(object sender, RoutedEventArgs e)
        {
            using (var fs = new FileStream(@"C:\dev\layout.xml", FileMode.Create, FileAccess.Write))
            {
                this.AppDockManager.SaveLayout(fs);
            }
        }

        //private void ButtonLoadOnClick(object sender, RoutedEventArgs e)
        //{
        //    string filePath = @"C:\dev\layout.xml";
        //    if (!File.Exists(filePath)) return;

        //    using (var fs = new FileStream(filePath, FileMode.Open, FileAccess.Read))
        //    {
        //        this.AppDockManager.LoadLayout(fs);
        //    }
        //}

        // Handle the InitializePaneContent event to add content to missing panes
        //private void DockManagerOnInitializePaneContent(object sender,InitializePaneContentEventArgs e)
        //{
        //    var panesNumber = AppDockManager.GetPanes(PaneNavigationOrder.ActivationOrder).Count() + 1;
        //    var tag = "Pane :" + panesNumber + Environment.NewLine + e.NewPane.SerializationId;
        //    //reconstruct the tab
        //    var newPane = new ContentPane()
        //    {
        //        Name = "Pane" + e.NewPane.SerializationId.Replace("-", ""),
        //        Header = "Pane " + panesNumber,
        //        SerializationId = e.NewPane.SerializationId,
        //        IsEnabled = true,
        //        Tag = tag,
        //        Visibility = Visibility.Visible,
        //        Content = new ContentUserControl(tag)
        //    };
            
        //    //this.MainTabGroupPane.Items.Add(newPane);
        //}
    }
}
